# Yorkshire Puddings

Makes 6 good sized Yorkshire puddings, the way my mum taught me

4.5 stars out 5 based on 35 reviews

### Ingredients

- 1 egg
- 75g plain flour
- 70ml milk
- 60ml water
- Pinch of salt

### Time

- Preparation 10 mins
- Cook 25 mins

### Instructions

1. Pre-heat oven to 230C or gas mark 8. Pour the vegetable oil evenly into 2 x 4-hole Yorkshire pudding tins and place in the oven to heat through.
2. To make the batter, add all the flour into a bowl and beat in the eggs until smooth. Gradually add the milk and water while beating the mixture. It should be smooth and without lumps. Finally add a pinch of salt.
3. Make sure the oil is piping hot before pouring the batter evenly into the tins. Place in the oven for 20-25 minutes until pudding have risen and look golden brown

### Nutrition

- Calories: 125
- Fat: 3.2g
- Cholesterol: 77mg

(Amount per pudding)

Published on 27 Oct 2011 by Glenn Jones

Photo by dithie